@@ -22,6 +22,7 @@
 (declare-function ai-code--insert-prompt "ai-code-prompt-mode" (prompt-text))
 (declare-function ai-code--process-word-for-filepath "ai-code-prompt-mode" (word git-root-truename))
 (declare-function ai-code-call-gptel-sync "ai-code-prompt-mode" (prompt))
+(declare-function ai-code--resolve-auto-test-suffix-for-send "ai-code")
 (declare-function ai-code-backends-infra--session-buffer-p "ai-code-backends-infra" (buffer))
 (declare-function projectile-project-root "projectile")
 (declare-function ai-code-run-test "ai-code-agile")
@@ -37,6 +38,13 @@
 (defvar ai-code-auto-test-type)
 (defvar ai-code-auto-test-suffix)
 (defvar ai-code-cli)
+(defvar ai-code-task-use-gptel-filename)
+
+(defun ai-code--resolve-auto-test-suffix-for-current-send ()
+  "Return auto test suffix for this send action in file operations."
+  (if (fboundp 'ai-code--resolve-auto-test-suffix-for-send)
+      (ai-code--resolve-auto-test-suffix-for-send)
+    ai-code-auto-test-suffix))
 
 ;;;###autoload
 (defun ai-code-copy-buffer-file-name-to-clipboard (&optional arg)
@@ -202,7 +210,7 @@ and runs it in a compilation buffer."
   (let* ((prompt (ai-code-read-string "Prompt: "))
          (suffix-parts (delq nil (list ai-code-prompt-suffix
                                        (when ai-code-auto-test-type
-                                         ai-code-auto-test-suffix))))
+                                         (ai-code--resolve-auto-test-suffix-for-current-send)))))
          (suffix (when (and ai-code-use-prompt-suffix suffix-parts)
                    (string-join suffix-parts ", ")))
          (prompt-with-suffix (if suffix
@@ -553,6 +561,77 @@ toggle dedication for every window in the current frame."
         (message "Window dedication updated: %s" (mapconcat #'identity (nreverse results) ", "))
       (message "No file buffers found in target windows"))))
 
+(defun ai-code--sanitize-generated-path-name (name)
+  "Sanitize generated NAME for file or directory creation."
+  (let ((clean-name (downcase (string-trim (or name "")))))
+    (setq clean-name (or (car (split-string clean-name "\n" t)) ""))
+    (setq clean-name (replace-regexp-in-string "[^a-z0-9._/-]" "_" clean-name))
+    (setq clean-name (replace-regexp-in-string "_+" "_" clean-name))
+    (setq clean-name (replace-regexp-in-string "/+" "/" clean-name))
+    (setq clean-name (replace-regexp-in-string "^[_./]+\\|[_./]+$" "" clean-name))
+    clean-name))
+
+(defun ai-code--generate-file-or-dir-name-with-gptel (description target-type)
+  "Generate a file or directory name for DESCRIPTION and TARGET-TYPE.
+TARGET-TYPE should be either \"file\" or \"directory\"."
+  (let* ((prompt
+          (format
+           (concat "Generate one concise lowercase %s name for this request: %s\n"
+                   "Rules: return only the name, no explanation, no markdown, no quotes, max 60 chars.\n"
+                   "Use letters/numbers/_/./- and / for nested path if needed.")
+           target-type
+           description))
+         (generated-name (condition-case nil
+                             (ai-code-call-gptel-sync prompt)
+                           (error description))))
+    (ai-code--sanitize-generated-path-name generated-name)))
+
+;;;###autoload
+(defun ai-code-create-file-or-dir ()
+  "Generate and create a new file or directory under current directory.
+Use GPTel to generate the name, ask user to confirm, then create and open
+it in another window."
+  (interactive)
+  (let* ((current-dir (if (derived-mode-p 'dired-mode)
+                          (dired-current-directory)
+                        default-directory))
+         (target-type (completing-read "Create target type: "
+                                       '("file" "directory")
+                                       nil t nil nil "file"))
+         (description (read-string (format "Describe the %s to create: " target-type))))
+    (when (string-empty-p (string-trim description))
+      (user-error "Description cannot be empty"))
+    (let* ((generated-name (if (and (boundp 'ai-code-task-use-gptel-filename)
+                                    ai-code-task-use-gptel-filename)
+                               (ai-code--generate-file-or-dir-name-with-gptel description target-type)
+                             (ai-code--sanitize-generated-path-name description)))
+           (fallback-name (if (string-empty-p generated-name)
+                              (if (string= target-type "directory")
+                                  "new_dir"
+                                "new_file.txt")
+                            generated-name))
+           (confirmed-name
+            (read-string (format "Confirm %s name (will create under %s): "
+                                 target-type
+                                 (abbreviate-file-name current-dir))
+                         fallback-name))
+           (sanitized-name (ai-code--sanitize-generated-path-name confirmed-name)))
+      (when (string-empty-p sanitized-name)
+        (user-error "Confirmed name cannot be empty"))
+      (let ((target-path (expand-file-name sanitized-name current-dir)))
+        (if (string= target-type "directory")
+            (progn
+              (unless (file-directory-p target-path)
+                (make-directory target-path t))
+              (dired-other-window target-path)
+              (message "Opened directory: %s" target-path))
+          (progn
+            (unless (file-exists-p target-path)
+              (make-directory (file-name-directory target-path) t)
+              (write-region "" nil target-path nil 'silent))
+            (find-file-other-window target-path)
+            (message "Opened file: %s" target-path)))))))
+
 (provide 'ai-code-file)
 
 ;;; ai-code-file.el ends here
