@@ -28,6 +28,16 @@ Candidate values:
   :group 'ai-code)
 
 (declare-function ai-code--insert-prompt "ai-code-prompt-mode" (prompt-text))
+(declare-function ai-code--ensure-files-directory "ai-code-prompt-mode" ())
+
+(defvar ai-code-files-dir-name)
+
+(defun ai-code--git-ignored-repo-file-p (file root)
+  "Return non-nil when FILE should be ignored for repo candidates."
+  (when (and file root)
+    (let ((ignore-dir (file-truename (expand-file-name ai-code-files-dir-name root)))
+          (truename (file-truename file)))
+      (string-prefix-p ignore-dir truename))))
 
 ;;;###autoload
 (defun ai-code-pull-or-review-diff-file ()
@@ -39,11 +49,15 @@ Otherwise, generate the diff."
       (let* ((file-name (file-name-nondirectory buffer-file-name))
              (init-prompt (format "Code review for %s. Use relevant file in repository as context.
 
-**Focus**: Quality, security, performance, patterns
-**Format**: Location, issue, solution, priority (High/Medium/Low)
+**Review Steps**:
+1. **Requirement Fit** (Top Priority): Verify if the code change fulfills the requirement below. Identify gaps or missing implementations.
+2. **Code Quality**: Check for quality, security, performance, and coding patterns.
+3. **Issues Found**: For each issue: Location, Issue, Solution, Priority (High/Medium/Low)
 
-Provide overall assessment." file-name))
-             (prompt (ai-code-read-string "Enter diff review prompt: " init-prompt)))
+Provide overall assessment.
+
+**Requirement**: " file-name))
+             (prompt (ai-code-read-string "Enter review prompt (type requirement at end): " init-prompt)))
         (ai-code--insert-prompt prompt))
     (ai-code--magit-generate-feature-branch-diff-file)))
 
@@ -175,19 +189,20 @@ DIFF-PARAMS is a plist with :type (`'commit`, `'base-vs-head`, `'branch-range`),
   (find-file diff-file)
   (message "Generated diff file: %s" diff-file))
 
-(defun ai-code--handle-staged-diff-generation (git-root)
+(defun ai-code--handle-staged-diff-generation (_git-root)
   "Handle generation of diff for staged change.
-GIT-ROOT is the root directory of the Git repository."
-  (let* ((diff-file-name-part "staged")
-         (diff-file (expand-file-name (concat diff-file-name-part ".diff") git-root)))
+_GIT-ROOT is unused but kept for API compatibility."
+  (let* ((files-dir (ai-code--ensure-files-directory))
+         (diff-file-name-part "staged")
+         (diff-file (expand-file-name (concat diff-file-name-part ".diff") files-dir)))
     (ai-code--generate-staged-diff diff-file)
     diff-file))
 
-(defun ai-code--handle-base-vs-head-diff-generation (git-root
+(defun ai-code--handle-base-vs-head-diff-generation (_git-root
                                                       &optional
                                                       open-in-browser)
   "Handle generation of diff between a base branch and HEAD.
-GIT-ROOT is the root directory of the Git repository.
+_GIT-ROOT is unused but kept for API compatibility.
 If OPEN-IN-BROWSER is non-nil, only open the diff in GitHub web
 interface without generating file."
   (let* ((base-branch (ai-code-read-string "Base branch name: "))
@@ -196,8 +211,9 @@ interface without generating file."
         (progn
           (ai-code--open-git-web-compare base-branch (or current-branch "HEAD"))
           nil)  ; Return nil since no file was generated
-      (let* ((diff-file-name-part (concat (replace-regexp-in-string "/" "-" base-branch) ".HEAD"))
-             (diff-file (expand-file-name (concat diff-file-name-part ".diff") git-root))
+      (let* ((files-dir (ai-code--ensure-files-directory))
+             (diff-file-name-part (concat (replace-regexp-in-string "/" "-" base-branch) ".HEAD"))
+             (diff-file (expand-file-name (concat diff-file-name-part ".diff") files-dir))
              (diff-params (list :type 'base-vs-head
                                 :base-branch base-branch
                                 :feature-branch "HEAD"
@@ -205,11 +221,11 @@ interface without generating file."
         (ai-code--generate-branch-or-commit-diff diff-params diff-file)
         diff-file))))
 
-(defun ai-code--handle-branch-range-diff-generation (git-root
+(defun ai-code--handle-branch-range-diff-generation (_git-root
                                                       &optional
                                                       open-in-browser)
   "Handle generation of diff between a base and a feature branch.
-GIT-ROOT is the root directory of the Git repository.
+_GIT-ROOT is unused but kept for API compatibility.
 If OPEN-IN-BROWSER is non-nil, only open the diff in GitHub web
 interface without generating file."
   (let* ((base-branch (ai-code-read-string "Base branch name: "))
@@ -228,10 +244,11 @@ interface without generating file."
               (if (consp raw-scope-choice)
                   (cdr raw-scope-choice)
                 (cdr (assoc raw-scope-choice scope-alist))))
-        (let* ((diff-file-name-part (concat (replace-regexp-in-string "/" "-" base-branch)
+        (let* ((files-dir (ai-code--ensure-files-directory))
+               (diff-file-name-part (concat (replace-regexp-in-string "/" "-" base-branch)
                                            "."
                                            (replace-regexp-in-string "/" "-" feature-branch)))
-               (diff-file (expand-file-name (concat diff-file-name-part ".diff") git-root))
+               (diff-file (expand-file-name (concat diff-file-name-part ".diff") files-dir))
                (diff-params (list :type 'branch-range
                                    :base-branch base-branch
                                    :feature-branch feature-branch
@@ -240,10 +257,10 @@ interface without generating file."
           (ai-code--generate-branch-or-commit-diff diff-params diff-file)
           diff-file)))))
 
-(defun ai-code--handle-commit-diff-generation (git-root
+(defun ai-code--handle-commit-diff-generation (_git-root
                                                 &optional open-in-browser)
   "Handle generation of diff for a single commit.
-GIT-ROOT is the root directory of the Git repository.
+_GIT-ROOT is unused but kept for API compatibility.
 If OPEN-IN-BROWSER is non-nil, only open the commit in GitHub web
 interface without generating file."
   (let* ((commit-hash (ai-code-read-string "Commit hash: ")))
@@ -251,10 +268,11 @@ interface without generating file."
         (progn
           (ai-code--open-git-web-commit commit-hash)
           nil)  ; Return nil since no file was generated
-      (let* ((base-branch (concat commit-hash "^"))  ; Diff against parent
+      (let* ((files-dir (ai-code--ensure-files-directory))
+             (base-branch (concat commit-hash "^"))  ; Diff against parent
              (feature-branch commit-hash)
              (diff-file-name-part commit-hash)
-             (diff-file (expand-file-name (concat diff-file-name-part ".diff") git-root))
+             (diff-file (expand-file-name (concat diff-file-name-part ".diff") files-dir))
              (diff-params (list :type 'commit
                                 :base-branch base-branch
                                 :feature-branch feature-branch
@@ -279,9 +297,9 @@ interface without generating file."
       (cdr (assoc raw-diff-type-choice diff-type-alist)))))
 
 ;;; New helper for commit ranges
-(defun ai-code--handle-commit-range-diff-generation (git-root &optional open-in-browser)
+(defun ai-code--handle-commit-range-diff-generation (_git-root &optional open-in-browser)
   "Handle generation of diff between two commits (commit range).
-GIT-ROOT is the repository root directory.
+_GIT-ROOT is unused but kept for API compatibility.
 If OPEN-IN-BROWSER is non-nil, only open the diff in GitHub web interface
 without generating file."
   (let* ((raw-start (ai-code-read-string "Start commit or branch: "))
@@ -294,10 +312,11 @@ without generating file."
           (ai-code--open-git-web-compare start end)
           nil)  ; Return nil since no file was generated
       ;; Sanitize branch names for file path (replace "/" with "-")
-      (let* ((name-sanitized (concat (replace-regexp-in-string "/" "-" start)
+      (let* ((files-dir (ai-code--ensure-files-directory))
+             (name-sanitized (concat (replace-regexp-in-string "/" "-" start)
                                      ".."
                                      (replace-regexp-in-string "/" "-" end)))
-             (file      (expand-file-name (concat name-sanitized ".diff") git-root))
+             (file      (expand-file-name (concat name-sanitized ".diff") files-dir))
              ;; reuse branch-range plumbing (it will fetch and verify)
              (params    (list :type 'branch-range
                               :base-branch start
@@ -565,8 +584,7 @@ If not inside a Git repository, do nothing."
     (if (not git-root)
         (message "ai-code-update-git-ignore: not in a git repository, skipped")
       (let* ((gitignore-path (expand-file-name ".gitignore" git-root))
-             (required-entries (list ai-code-prompt-file-name
-                                     ai-code-notes-file-name
+             (required-entries (list (concat ai-code-files-dir-name "/")
                                      ".projectile"
                                      "GTAGS"
                                      "GRTAGS"
@@ -600,6 +618,64 @@ If not inside a Git repository, do nothing."
                        (mapconcat #'identity added ", ")))
           (message "ai-code-update-git-ignore: no updates needed"))))))
 
+;;;###autoload
+(defun ai-code--git-repo-recent-modified-files (base-dir limit)
+  "Return up to LIMIT most recently modified files under BASE-DIR.
+If BASE-DIR is in a Git repository, use `git ls-files' to enumerate files."
+  (let* ((git-root (magit-toplevel base-dir))
+         (root (or git-root base-dir))
+         (files (if git-root
+                    (let ((default-directory root))
+                      (mapcar (lambda (path)
+                                (expand-file-name path root))
+                              (magit-git-lines "ls-files")))
+                  (directory-files root t directory-files-no-dot-files-regexp)))
+         (file-times nil))
+    (dolist (file files)
+      (when (and (file-regular-p file)
+                 (not (ai-code--git-ignored-repo-file-p file root)))
+        (let* ((attrs (file-attributes file))
+               (mtime (file-attribute-modification-time attrs)))
+          (push (cons file mtime) file-times))))
+    (setq file-times (sort file-times
+                           (lambda (a b)
+                             (time-less-p (cdr b) (cdr a)))))
+    (let ((recent '())
+          (count 0))
+      (dolist (item file-times)
+        (when (< count limit)
+          (push (car item) recent)
+          (setq count (1+ count))))
+      (delete-dups (nreverse recent)))))
+
+;;;###autoload
+(defun ai-code-git-repo-recent-modified-files (prefix)
+  "Open or insert one of the most recently modified files in the repo or current dir.
+With no PREFIX argument, prompt for a recently modified file and open it
+with `find-file'.
+
+With a PREFIX argument (e.g., when called via `C-u'), prompt for a recently
+modified file and insert \"@\" followed by the selected filename into the
+buffer from which this command was invoked, instead of visiting the file."
+  (interactive "P")
+  (let* ((git-root (magit-toplevel))
+         (base-dir (or git-root default-directory))
+         (files (ai-code--git-repo-recent-modified-files base-dir 20))
+         (origin-buffer (current-buffer)))
+    (if (not files)
+        (message "ai-code-git-repo-recent-modified-files: no files found")
+      (let* ((candidates (mapcar (lambda (file)
+                                   (file-relative-name file base-dir))
+                                 files))
+             (choice (completing-read "Recent modified file: "
+                                      candidates nil t)))
+        (unless (string= choice "")
+          (if prefix
+              (when (buffer-live-p origin-buffer)
+                (with-current-buffer origin-buffer
+                  (insert "@" choice)))
+            (find-file (expand-file-name choice base-dir))))))))
+
 (provide 'ai-code-git)
 
 ;;; ai-code-git.el ends here
