@@ -1,8 +1,8 @@
 ;;; ai-code.el --- Unified interface for AI coding CLI such as Claude Code, Codex CLI, Gemini CLI, Copilot CLI, Opencode, Grok CLI, Aider CLI, etc -*- lexical-binding: t; -*-
 
 ;; Author: Kang Tu <tninja@gmail.com>
-;; Package-Version: 20260213.1730
-;; Package-Revision: c7767d6a9e6a
+;; Package-Version: 20260216.226
+;; Package-Revision: 69641032b816
 ;; Package-Requires: ((emacs "28.1") (transient "0.8.0") (magit "2.1.0"))
 ;; URL: https://github.com/tninja/ai-code-interface.el
 
@@ -37,8 +37,8 @@
 ;;   (global-set-key (kbd "C-c a") #'ai-code-menu)
 ;;   ;; Optional: Enable @ file completion in comments and AI sessions
 ;;   (ai-code-prompt-filepath-completion-mode 1)
-;;   ;; Optional: Ask AI to run test after code changes, for a tighter build-test loop
-;;   (setq ai-code-auto-test-type 'test-after-change)
+;;   ;; Optional: Configure AI test prompting mode (e.g., ask about running tests/TDD) for a tighter build-test loop
+;;   (setq ai-code-auto-test-type 'ask-me)
 ;;   ;; Optional: In the AI session buffer (Evil normal state), SPC triggers the prompt entry UI
 ;;   (with-eval-after-load 'evil (ai-code-backends-infra-evil-setup))
 ;;   (global-auto-revert-mode 1)
@@ -146,19 +146,60 @@ with a newline separator."
     (concat "Follow TDD principles - write the failing test first, then implement the minimal code to make it pass. Only update test and source code. Run the tests and follow up with the test result (fix code if there is error)."
             (or pattern ""))))
 
+(defconst ai-code--auto-test-type-ask-choices
+  '(("Run tests after code change" . test-after-change)
+    ("Test driven development: Write test first" . tdd)
+    ("Do not run tests" . nil))
+  "Choices for resolving the auto test suffix when `ai-code-auto-test-type` is `ask-me`.")
+
+(defun ai-code--read-auto-test-type-choice ()
+  "Read and return one prompt test type for this send action."
+  (let* ((choice (completing-read "Choose test prompt type for this send: "
+                                  (mapcar #'car ai-code--auto-test-type-ask-choices)
+                                  nil t nil nil
+                                  (caar ai-code--auto-test-type-ask-choices)))
+         (choice-cell (assoc choice ai-code--auto-test-type-ask-choices)))
+    (if choice-cell
+        (cdr choice-cell)
+      'test-after-change)))
+
+(defun ai-code--resolve-auto-test-type-for-send ()
+  "Resolve the concrete auto test type for the current send action."
+  (pcase ai-code-auto-test-type
+    ('ask-me (ai-code--read-auto-test-type-choice))
+    ('test-after-change 'test-after-change)
+    ('tdd 'tdd)
+    (_ nil)))
+
+(defun ai-code--auto-test-suffix-for-type (type)
+  "Return prompt suffix for auto test TYPE."
+  (pcase type
+    ('test-after-change ai-code-test-after-code-change-suffix)
+    ('tdd (ai-code--test-after-code-change--resolve-tdd-suffix))
+    (_ nil)))
+
+(defun ai-code--resolve-auto-test-suffix-for-send ()
+  "Resolve auto test suffix for the current send action."
+  (ai-code--auto-test-suffix-for-type
+   (ai-code--resolve-auto-test-type-for-send)))
+
+(defun ai-code--with-auto-test-suffix-for-send (orig-fun prompt-text)
+  "Resolve and bind auto test suffix before sending PROMPT-TEXT."
+  (let ((ai-code-auto-test-suffix (ai-code--resolve-auto-test-suffix-for-send)))
+    (funcall orig-fun prompt-text)))
+
+(unless (advice-member-p #'ai-code--with-auto-test-suffix-for-send
+                         'ai-code--write-prompt-to-file-and-send)
+  (advice-add 'ai-code--write-prompt-to-file-and-send
+              :around
+              #'ai-code--with-auto-test-suffix-for-send))
+
 (defun ai-code--test-after-code-change--set (symbol value)
   "Set SYMBOL to VALUE and update related suffix behavior."
   (set-default symbol value)
   (set symbol value)
-  (pcase value
-    ('test-after-change
-     (setq ai-code-auto-test-suffix
-           ai-code-test-after-code-change-suffix))
-    ('tdd
-     (setq ai-code-auto-test-suffix
-           (ai-code--test-after-code-change--resolve-tdd-suffix)))
-    (_
-     (setq ai-code-auto-test-suffix nil))))
+  (setq ai-code-auto-test-suffix
+        (ai-code--auto-test-suffix-for-type value)))
 
 (defun ai-code--apply-auto-test-type (value)
   "Set `ai-code-auto-test-type` and refresh related suffix."
@@ -170,6 +211,7 @@ with a newline separator."
   "Select how prompts request tests after code changes."
   :type '(choice (const :tag "Use test after code change prompt" test-after-change)
                  (const :tag "Use TDD Red+Green prompt" tdd)
+                 (const :tag "Ask every time" ask-me)
                  (const :tag "Off" nil))
   :set #'ai-code--test-after-code-change--set
   :group 'ai-code)
@@ -276,6 +318,7 @@ Otherwise switch to AI CLI buffer."
   :reader (lambda (_prompt _initial-input _history)
             (let* ((choices '(("Use test after code change prompt" . test-after-change)
                               ("Use TDD Red+Green prompt" . tdd)
+                              ("Ask every time" . ask-me)
                               ("Off" . nil)))
                    (choice (completing-read "Test after code change: "
                                             (mapcar #'car choices)
@@ -284,7 +327,9 @@ Otherwise switch to AI CLI buffer."
                 (ai-code--apply-auto-test-type value)
                 (message "Auto test type set to %s; prompt suffix is now %s"
                          (or value "off")
-                         (or ai-code-auto-test-suffix "cleared"))
+                         (if (eq value 'ask-me)
+                             "ask each send"
+                           (or ai-code-auto-test-suffix "cleared")))
                 value))))
 
 (defun ai-code--select-backend-description (&rest _)
@@ -316,6 +361,7 @@ Shows the current backend label to the right."
     ("x" "Explain code in scope" ai-code-explain)
     ("<SPC>" "Send command (C-u: context)" ai-code-send-command)
     ("@" "Add context (C-u: clear)" ai-code-context-action)
+    ("C" "Create file or dir with AI" ai-code-create-file-or-dir)
     ]
 
    ["AI Agile Development"
